@@ -190,3 +190,18 @@ def test_site_group_access():
 
     headers = {'Authorization': sid}
     assert requests.get(url, headers=headers).status_code == 200
+
+
+def test_request_access():
+    url = urls.base + 'request-and-body'
+    req = requests.post(url, data={'z': 1}, headers={'testheader': 'testheader-value'})
+    resp = req.json()
+    assert 'testheader'.upper() in resp['headers']
+    assert resp['body'] == {'z': '1'}
+
+
+def test_raw_request():
+    url = urls.base + 'request-raw-body'
+    req = requests.post(url, data={'z': 1}, headers={'testheader': 'testheader-value'})
+    resp = req.json()
+    assert 'testheader'.upper() in resp['headers']
